@@ -1,7 +1,7 @@
 from einops.layers.torch import Rearrange as _Rearrange
 
 from tensorneko_util.util import AbstractServer, dispatch, AverageMeter, tensorneko_util_path
-from tensorneko_util.util.fp import Seq, AbstractSeq, curry, Some, Empty, F, Stream, return_option, Option, _, __
+from tensorneko_util.util.fp import Seq, AbstractSeq, curry, F, Stream, return_option, Option, Monad, Eval, _, __
 from tensorneko_util.util import ref, Timer, Singleton
 from tensorneko_util.util.eventbus import Event, EventBus, EventHandler, subscribe, subscribe_async, \
     subscribe_process, subscribe_thread
@@ -47,8 +47,8 @@ __all__ = [
     "Seq",
     "return_option",
     "Option",
-    "Some",
-    "Empty",
+    "Monad",
+    "Eval",
     "Rearrange",
     "_",
     "F",
